@@ -1,4 +1,4 @@
-/* $Id: glibtop_server.h,v 1.27 2004/07/17 12:01:24 bdejean Exp $ */
+/* $Id: glibtop_server.h,v 1.28 2004/08/03 11:40:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -41,12 +41,19 @@ G_BEGIN_DECLS
 
 unsigned get_pageshift();
 
+static inline char*
+next_token(const char *p)
+{
+	while (isspace(*p)) p++;
+	return (char*) p;
+}
 
 static inline char *
 skip_token (const char *p)
 {
-	while (isspace(*p)) p++;
+	p = next_token(p);
 	while (*p && !isspace(*p)) p++;
+	p = next_token(p);
 	return (char *)p;
 }
 
