@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.16 2003/10/20 15:20:08 hadess Exp $ */
+/* $Id: proclist.c,v 1.19 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -55,7 +55,7 @@ glibtop_init_proclist_s (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	DIR *proc;
 	struct dirent *entry;
@@ -96,8 +96,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	      if(s_stat(buffer, &statb) < 0)
 		 return NULL;
 	   }
-	   if(!(pids_chain = g_malloc(sizeof(unsigned))))
-	      return NULL;
+	   pids_chain = g_malloc(sizeof(unsigned));
 	   *pids_chain = pid;
 	   return pids_chain;
 	}
@@ -207,12 +206,12 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		}
 
 		/* pids is now big enough to hold at least one single pid. */
-		
+
 		pids [count++] = pid;
 
 		total++;
 	}
-	
+
 	s_closedir (proc);
 
 	/* count is only zero if an error occured (one a running Linux system,
@@ -224,15 +223,15 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	 * g_malloc if pids_chain is NULL. We just calculate the
 	 * new size and copy pids to the beginning of the newly allocated
 	 * block. */
-	
+
 	new_size = pids_size + count * sizeof (unsigned);
-	
+
 	pids_chain = g_realloc (pids_chain, new_size);
-	
+
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
-	
+
 	pids_size = new_size;
-	
+
 	pids_offset += BLOCK_COUNT;
 
 	/* Since everything is ok now, we can set buf->flags, fill in the
